@@ -25,7 +25,8 @@ from avocado.core.parser import HintParser
 from avocado.core.resolver import ReferenceResolutionResult, resolve
 from avocado.core.settings import settings
 from avocado.core.tags import filter_test_tags, filter_test_tags_runnable
-from avocado.core.test import DryRunTest, Test
+from avocado.core.test import DryRunTest
+from avocado.core.tree import TreeNode
 from avocado.core.varianter import Varianter, is_empty_variant
 
 
@@ -213,16 +214,6 @@ class TestSuite:
             self._increment_dict_key_counter(stats, test.kind)
         return stats
 
-    def _get_stats_from_runner(self):
-        stats = {}
-        mapping = loader.get_type_label_mapping()
-
-        for cls, _ in self.tests:
-            if isinstance(cls, str):
-                cls = Test
-            self._increment_dict_key_counter(stats, mapping[cls])
-        return stats
-
     def _get_tags_stats_from_nrunner(self):
         stats = {}
         for runnable in self.tests:
@@ -233,14 +224,6 @@ class TestSuite:
                 self._increment_dict_key_counter(stats, tag)
         return stats
 
-    def _get_tags_stats_from_runner(self):
-        stats = {}
-        for test in self.tests:
-            params = test[1]
-            for tag in params.get('tags', {}):
-                self._increment_dict_key_counter(stats, tag)
-        return stats
-
     @staticmethod
     def _increment_dict_key_counter(dict_object, key):
         try:
@@ -276,9 +259,7 @@ class TestSuite:
     def stats(self):
         """Return a statistics dict with the current tests."""
         runner_name = self.config.get('run.test_runner')
-        if runner_name == 'runner':
-            return self._get_stats_from_runner()
-        elif runner_name == 'nrunner':
+        if runner_name == 'nrunner':
             return self._get_stats_from_nrunner()
         return {}
 
@@ -297,9 +278,7 @@ class TestSuite:
     def tags_stats(self):
         """Return a statistics dict with the current tests tags."""
         runner_name = self.config.get('run.test_runner')
-        if runner_name == 'runner':
-            return self._get_tags_stats_from_runner()
-        elif runner_name == 'nrunner':
+        if runner_name == 'nrunner':
             return self._get_tags_stats_from_nrunner()
         return {}
 
@@ -329,6 +308,32 @@ class TestSuite:
             self._variants = variants
         return self._variants
 
+    def get_test_variants(self):
+        """Computes test variants based on the parameters"""
+
+        if self.test_parameters:
+            paths = ['/']
+            tree_nodes = TreeNode().get_node(paths[0], True)
+            tree_nodes.value = self.test_parameters
+            variant = {"variant": tree_nodes,
+                       "variant_id": None,
+                       "paths": paths}
+            test_variant = [(test, variant) for test in self.tests]
+
+        else:
+            # let's use variants when parameters are not available
+            # define execution order
+            execution_order = self.config.get('run.execution_order')
+            if execution_order == "variants-per-test":
+                test_variant = [(test, variant)
+                                for test in self.tests
+                                for variant in self.variants.itertests()]
+            elif execution_order == "tests-per-variant":
+                test_variant = [(test, variant)
+                                for variant in self.variants.itertests()
+                                for test in self.tests]
+        return test_variant
+
     def run(self, job):
         """Run this test suite with the job context in mind.
 
