@@ -19,6 +19,7 @@ Test resolver for builtin test types
 import os
 import re
 
+from avocado.core.extension_manager import PluginPriority
 from avocado.core.nrunner import Runnable
 from avocado.core.plugin_interfaces import Resolver
 from avocado.core.references import reference_split
@@ -31,6 +32,7 @@ class ExecTestResolver(Resolver):
 
     name = 'exec-test'
     description = 'Test resolver for executable files to be handled as tests'
+    priority = PluginPriority.VERY_LOW
 
     def resolve(self, reference):
 
@@ -59,8 +61,8 @@ def python_resolver(name, reference, find_tests):
     # disabled tests not needed here
     class_methods_info, _ = find_tests(module_path)
     runnables = []
-    for klass, methods_tags_reqs in class_methods_info.items():
-        for (method, tags, reqs) in methods_tags_reqs:
+    for klass, methods_tags_depens in class_methods_info.items():
+        for (method, tags, depens) in methods_tags_depens:
             klass_method = "%s.%s" % (klass, method)
             if tests_filter is not None and not tests_filter.search(klass_method):
                 continue
@@ -68,7 +70,7 @@ def python_resolver(name, reference, find_tests):
             runnables.append(Runnable(name,
                                       uri=uri,
                                       tags=tags,
-                                      requirements=reqs))
+                                      dependencies=depens))
     if runnables:
         return ReferenceResolution(reference,
                                    ReferenceResolutionResult.SUCCESS,
@@ -98,6 +100,7 @@ class AvocadoInstrumentedResolver(Resolver):
 
     name = 'avocado-instrumented'
     description = 'Test resolver for Avocado Instrumented tests'
+    priority = PluginPriority.HIGH
 
     def resolve(self, reference):
         return python_resolver(AvocadoInstrumentedResolver.name,
@@ -109,6 +112,7 @@ class TapResolver(Resolver):
 
     name = 'tap'
     description = 'Test resolver for executable files to be handled as TAP tests'
+    priority = PluginPriority.LAST_RESORT
 
     def resolve(self, reference):
 
