@@ -20,7 +20,7 @@ class CAbort(Test):
         source = self.params.get('source', default='abort.c')
         c_file = self.get_data(source)
         if c_file is None:
-            self.cancel('Test is missing data file %s' % source)
+            self.cancel(f'Test is missing data file {source}')
         c_file_name = os.path.basename(c_file)
         dest_c_file = os.path.join(self.workdir, c_file_name)
         shutil.copy(c_file, dest_c_file)
