@@ -6,7 +6,7 @@ from avocado.core import exit_codes
 from avocado.utils import process, script
 from selftests.utils import AVOCADO, BASEDIR, TestCaseTmpDir
 
-SCRIPT_CONTENT = """#!/bin/sh
+SCRIPT_CONTENT = (f"""#!/bin/sh
 echo "Avocado Version: $AVOCADO_VERSION"
 echo "Avocado Test basedir: $AVOCADO_TEST_BASEDIR"
 echo "Avocado Test workdir: $AVOCADO_TEST_WORKDIR"
@@ -14,13 +14,13 @@ echo "Avocado Test logdir: $AVOCADO_TEST_LOGDIR"
 echo "Avocado Test logfile: $AVOCADO_TEST_LOGFILE"
 echo "Avocado Test outputdir: $AVOCADO_TEST_OUTPUTDIR"
 
-test "$AVOCADO_VERSION" = "{version}" -a \
+test "$AVOCADO_VERSION" = "{VERSION}" -a \
      -d "$AVOCADO_TEST_BASEDIR" -a \
      -d "$AVOCADO_TEST_WORKDIR" -a \
      -d "$AVOCADO_TEST_LOGDIR" -a \
      -f "$AVOCADO_TEST_LOGFILE" -a \
      -d "$AVOCADO_TEST_OUTPUTDIR"
-""".format(version=VERSION)
+""")
 
 
 class EnvironmentVariablesTest(TestCaseTmpDir):
@@ -35,14 +35,12 @@ class EnvironmentVariablesTest(TestCaseTmpDir):
 
     def test_environment_vars(self):
         os.chdir(BASEDIR)
-        cmd_line = ('%s run --job-results-dir %s %s'
-                    ' --test-runner=runner'
-                    % (AVOCADO, self.tmpdir.name, self.script.path))
+        cmd_line = (f'{AVOCADO} run --job-results-dir {self.tmpdir.name} '
+                    f'{self.script.path} --test-runner=runner')
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
         self.assertEqual(result.exit_status, expected_rc,
-                         "Avocado did not return rc %d:\n%s" %
-                         (expected_rc, result))
+                         f"Avocado did not return rc {expected_rc}:\n{result}")
 
     def tearDown(self):
         super().tearDown()
