@@ -20,7 +20,7 @@ class StateMachine(TestCase):
         number_of_workers = 8
 
         runnable = Runnable("noop", "noop")
-        runtime_tasks = [RuntimeTask(Task(runnable, "%03i" % _))
+        runtime_tasks = [RuntimeTask(Task(runnable, "%03i" % _))  # pylint: disable=C0209
                          for _ in range(1, number_of_tasks + 1)]
         spawner = Spawner()
         status_repo = StatusRepo()
